-- This Source Code Form is subject to the terms of the bCDDL, v. 1.1.
-- If a copy of the bCDDL was not distributed with this
-- file, You can obtain one at http://beamng.com/bCDDL-1.1.txt

local M = {}
M.type = "auxilliary"
M.relevantDevice = nil 
M.clutchRatio = 0



local min = math.min
local max = math.max


local flapsOff = 0.0
local flapsTakeoff = 0.4
local flapsLanding = 1.0
local flapStates = {flapsOff, flapsLanding, flapsTakeoff}  -- Changed order: landing comes after off, then takeoff
local currentFlapIndex = 1  -- Start with Flaps Up (index 1)

local function toggleFlaps()
    -- Cycle to the next flap state
    currentFlapIndex = (currentFlapIndex % #flapStates) + 1
    electrics.values.flap = flapStates[currentFlapIndex]  -- Set electric value based on the current flap state

    -- Display message based on the current flap state
    if currentFlapIndex == 1 then
        gui.message("Flaps Up", 2, "flapmessage")
    elseif currentFlapIndex == 2 then
        gui.message("Landing Flaps", 2, "flapmessage")  -- Changed order to match new index
    elseif currentFlapIndex == 3 then
        gui.message("Takeoff Flaps", 2, "flapmessage")  -- Changed order to match new index
    end
    
    -- Set electric value for hydraulic input
    electrics.values.flap_position = electrics.values.flap  -- This value can be used in your hydraulic system
end

  
          

local function onReset()


    electrics.values.throttleup = 0
    electrics.values.throttledown = 0
    electrics.values.throttleds8 = 0

   
end



local function updateGFX(dt)


            
    local throttle = electrics.values.throttleds8 or 0

    throttle = min(max(throttle + (electrics.values.throttleup * dt * 0.5) - (electrics.values.throttledown * dt * 0.5), 0), 1)
    electrics.values.throttle = throttle

    electrics.values.throttleds8 = throttle


    

    electrics.values.clutch = 0
    electrics.values.clutchRatio = 1
    
end







M.onInit    = onReset
M.onReset   = onReset
M.updateGFX = updateGFX
M.toggleFlaps = toggleFlaps



return M